From 6abdd39b626299ac59d89ee35b4d17686d81f62d Mon Sep 17 00:00:00 2001
From: Qiuxu Zhuo <qiuxu.zhuo@intel.com>
Date: Wed, 26 Oct 2022 13:34:26 +0800
Subject: [PATCH 1/1] EDAC/igen6: Fix spurious errors on driver load

The In-band ECC error log register may be initialized with the value
~0ULL that results in reporting spurious errors on driver load as below.

  EDAC igen6 MC1: HANDLING IBECC MEMORY ERROR
  EDAC igen6 MC1: ADDR 0x7fffffffe0
  EDAC igen6 MC0: HANDLING IBECC MEMORY ERROR
  EDAC igen6 MC0: ADDR 0x7fffffffe0
  EDAC igen6: v2.5

Fix these spurious errors by filtering them out.

Reported-by: Orion Poplawski <orion@nwra.com>
Signed-off-by: Qiuxu Zhuo <qiuxu.zhuo@intel.com>
---
 drivers/edac/igen6_edac.c | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/drivers/edac/igen6_edac.c b/drivers/edac/igen6_edac.c
index a07bbfd075d0..d700144957da 100644
--- a/drivers/edac/igen6_edac.c
+++ b/drivers/edac/igen6_edac.c
@@ -653,7 +653,7 @@ static int ecclog_handler(void)
 		/* errsts_clear() isn't NMI-safe. Delay it in the IRQ context */
 
 		ecclog = ecclog_read_and_clear(imc);
-		if (!ecclog)
+		if (!ecclog || ecclog == ~0ULL)
 			continue;
 
 		if (!ecclog_gen_pool_add(i, ecclog))
-- 
2.17.1

